import sys
from src.utilities.running_os import running_os
from src.print.anim_print import animated_print
from src.input.anim_input import animated_input
from src.console.clear_console import clear_console
from src.input.ask_input import ask_input
from src.string.palindrom import ispalin


def ispalin(string,onlylow=True):
    temp_list= [[],[]]
    if onlylow:
        for i in string.lower():
            temp_list[0].append(i)
    elif onlylow == False:
        for i in string:
            temp_list[0].append(i)
    temp_list[1]=temp_list[0][::-1]
    if temp_list[0] == temp_list[1]: return True
    else: return False


from smischlib import running_os
from os import system
def clear_console(form="full"):
    if form == "full":
        if running_os() == "win":
            system("cls")
        else:
            system("clear")
    elif form == "line":
        print("\033[A\033[K", end="") #presunutie o poličko spať "\033[A", zmazanie riadka "\033[K"
    


from smischlib import animated_input
def ask_input(prompt="Example prompt for input:",datatype="str",type="animated",delay=0.05):
    while True:
        if datatype == "str":
            if type == "animated":
                a = animated_input(prompt,delay)
                return a
            else:
                a = input(prompt)
                return a
        elif datatype == "int":
            try:
                if type == "animated":
                    a = int(animated_input(prompt,delay))
                    return a
                else:
                    a = int(input(prompt))
                    return a
            except: pass


import sys
import time

def animated_input(prompt="Example prompt for input:", delay=0.05):
    result = ""
    for character in prompt:
        sys.stdout.write(character)
        sys.stdout.flush()
        time.sleep(delay)
    while True:
        key = sys.stdin.read(1)
        if key == "\n" or key == "\r":
            break
        result += key
        #sys.stdout.write(key)
        #sys.stdout.flush()
    return result